@@ -165,6 +165,8 @@ pool_start_query(POOL_QUERY_CONTEXT * query_context, char *query, int len, Node
 			query_context->temp_cache = pool_create_temp_query_cache(query);
 		pool_set_query_in_progress();
 		query_context->skip_cache_commit = false;
+		query_context->atEnd = false;
+		query_context->partial_fetch = false;
 		session_context->query_context = query_context;
 		MemoryContextSwitchTo(old_context);
 	}
@@ -968,7 +970,7 @@ pool_send_and_wait(POOL_QUERY_CONTEXT * query_context,
 		 * that any session object (i.e. named statement) does not remain in
 		 * the last session.
 		 */
-		if (per_node_error_log(backend, i, string, "pool_send_and_wait: Error or notice message from backend: ", true) == 'E')
+		if (per_node_error_log(backend, i, string, "pool_send_and_wait: Error or notice message from backend", true) == 'E')
 			reset_query_error = true;
 	}
 
@@ -1180,7 +1182,7 @@ pool_extended_send_and_wait(POOL_QUERY_CONTEXT * query_context,
 			 * does not report what statement caused that error and make users
 			 * confused.
 			 */
-			per_node_error_log(backend, i, str, "pool_send_and_wait: Error or notice message from backend: ", true);
+			per_node_error_log(backend, i, str, "pool_send_and_wait: Error or notice message from backend", true);
 		}
 	}
 
